@@ -30,6 +30,7 @@
 #include <QtGui/QStyleOption>
 
 #include <avogadro/global.h>
+#include <openbabel/babelconfig.h>
 
 namespace Avogadro {
 
@@ -56,21 +57,24 @@ namespace Avogadro {
       // Build up the SCM revision numbers if present
       QString scmVersion(SCM_REVISION);
       QString appVersion(VERSION);
+      QLatin1String obVersion(BABEL_VERSION);
       if (scmVersion.length())
-        appVersion += " (Git revision: " + scmVersion + ')';
+        appVersion += ' ' + QString(tr("(Git revision: %1)", "%1 is the Git revision number.")).arg(scmVersion);
       QString libVersion(Library::version());
       if (Library::scmRevision().length())
-        libVersion += " (Git revision: " + Library::scmRevision() + ')';
+        libVersion += ' ' + QString(tr("(Git revision: %1)", "%1 is the Git revision number.")).arg(Library::scmRevision());
 
       lbl->setText(
           tr("<h3>%1</h3>"
             "<br/><br/>Application Version: %2"
             "<br/><br/>Library Version: %3"
+            "<br/><br/>Open Babel Version: %4"
+            "<br/><br/>Qt Version: %5"
             "<br/><br/>For more information check the <a href=\"http://avogadro.openmolecules.net/\">Avogadro homepage</a>."
             "<br/><br/>The program is provided AS IS with NO WARRANTY OF ANY KIND,"
             " INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A"
             " PARTICULAR PURPOSE.<br/>"
-             ).arg(tr("Avogadro")).arg(appVersion).arg(libVersion));
+             ).arg(tr("Avogadro")).arg(appVersion).arg(libVersion).arg(obVersion).arg(QLatin1String(QT_VERSION_STR)));
 
       cmd->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
       cmd->setDefault(true);
