@@ -115,7 +115,7 @@ namespace Avogadro
         return 0;
       // Hard coding the PDB download URL - this could be used for other services
       m_network->get(QNetworkRequest(
-          QUrl("http://cactus.nci.nih.gov/chemical/structure/" + structureName + "/sdf")));
+          QUrl("http://cactus.nci.nih.gov/chemical/structure/" + structureName + "/sdf?get3d=true")));
 
       *m_moleculeName = structureName + ".sdf";
     }
@@ -163,7 +163,7 @@ namespace Avogadro
       QMessageBox::warning(qobject_cast<QWidget*>(parent()),
                            tr("Network Download Failed"),
                            tr("Network timeout or other error."));
-      delete reply;
+      reply->deleteLater();
       return;
     }
 
@@ -174,7 +174,7 @@ namespace Avogadro
       QMessageBox::warning(qobject_cast<QWidget*>(parent()),
                            tr("Network Download Failed"),
                            tr("Specified molecule could not be found: %1").arg(*m_moleculeName));
-      delete reply;
+      reply->deleteLater();
       return;
     }
 
@@ -196,7 +196,7 @@ namespace Avogadro
                            tr("Specified molecule could not be loaded: %1").arg(*m_moleculeName));
     }
     // We are responsible for deleting the reply object
-    delete reply;
+    reply->deleteLater();
   }
 
 } // End namespace Avogadro
