@@ -38,9 +38,11 @@
 #include <avogadro/atom.h>
 #include <avogadro/cube.h>
 #include <avogadro/mesh.h>
+#include <avogadro/color3f.h>
 #include <avogadro/meshgenerator.h>
 #include <avogadro/engine.h>
 #include <avogadro/neighborlist.h>
+#include <avogadro/glwidget.h>
 
 #include <Eigen/Core>
 
@@ -281,11 +283,11 @@ namespace Avogadro
 
     NeighborList *nbrList = new NeighborList(m_molecule, 7.0, false, 2);
 
-    std::vector<QColor> colors;
+    std::vector<Color3f> colors;
     for(unsigned int i=0; i < mesh->vertices().size(); ++i) {
       const Vector3f *v = mesh->vertex(i);
 
-      GLfloat red, green, blue;
+      float red, green, blue;
       double energy = 0.0;
 
       QList<Atom*> nbrAtoms = nbrList->nbrs(v);
@@ -295,29 +297,29 @@ namespace Avogadro
       }
 
       // Chemistry convention: red = negative, blue = positive
-      QColor color;
+      Color3f color;
       if (energy < 0.0) {
         red = -20.0*energy;
         if (red >= 1.0) {
-          color.setRgbF(1.0, 0.0, 0.0, 1.0);
+          color.set(1.0, 0.0, 0.0);
         }
         else {
           green = 1.0 - red;
-          color.setRgbF(red, green, 0.0, 1.0);
+          color.set(red, green, 0.0);
         }
       }
       else if (energy > 0.0) {
         blue = 20.0*energy;
         if (blue >= 1.0) {
-          color.setRgbF(0.0, 0.0, 1.0, 1.0);
+          color.set(0.0, 0.0, 1.0);
         }
         else {
           green = 1.0 - blue;
-          color.setRgbF(0.0, green, blue, 1.0);
+          color.set(0.0, green, blue);
         }
       }
       else
-        color.setRgbF(0.0, 1.0, 0.0, 1.0);
+        color.set(0.0, 1.0, 0.0);
 
       colors.push_back(color);
     }
@@ -707,11 +709,12 @@ namespace Avogadro
       case 2: { // Mesh calculated - now display it in an engine if possible
         if (!m_mesh2)
           m_calculationPhase = -1; // i.e. no calculation in progress any more
-
-        if (m_mesh1->stable() && m_mesh2 && m_mesh2->stable()) {
+        else if (m_mesh1->stable() && m_mesh2 && m_mesh2->stable()) {
           // The MO meshes have both been calculated
           m_calculationPhase = -1;
         }
+        else // Still calculating one of the meshes
+          return;
 
         Engine *engine = m_surfaceDialog->currentEngine();
         if (engine) {
@@ -736,7 +739,11 @@ namespace Avogadro
 
           engine->readSettings(settings);
           engine->setEnabled(true);
-          m_molecule->update();
+          // Trigger a repaint with the new mesh
+          /// FIXME Should be using m_molecule->update() to trigger a repaint in
+          /// all open displays, this currently causes crashes - need to track
+          /// down the cause.
+          m_glwidget->update();
         }
         else
           qDebug() << "Engine is null - no engines of this type loaded.";
